#line 2 "sequence/nbrfl.c"

#line 4 "sequence/nbrfl.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer nbrf_create_buffer
#define yy_delete_buffer nbrf_delete_buffer
#define yy_flex_debug nbrf_flex_debug
#define yy_init_buffer nbrf_init_buffer
#define yy_flush_buffer nbrf_flush_buffer
#define yy_load_buffer_state nbrf_load_buffer_state
#define yy_switch_to_buffer nbrf_switch_to_buffer
#define yyin nbrfin
#define yyleng nbrfleng
#define yylex nbrflex
#define yylineno nbrflineno
#define yyout nbrfout
#define yyrestart nbrfrestart
#define yytext nbrftext
#define yywrap nbrfwrap
#define yyalloc nbrfalloc
#define yyrealloc nbrfrealloc
#define yyfree nbrffree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#ifdef _LIBC
#include "namespace.h"
#endif
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/*	$NetBSD: flexint.h,v 1.1.1.1 2009/10/26 00:26:19 christos Exp $	*/

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE nbrfrestart(nbrfin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int nbrfleng;

extern FILE *nbrfin, *nbrfout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up nbrftext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up nbrftext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via nbrfrestart()), so that the user can continue scanning by
	 * just pointing nbrfin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when nbrftext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int nbrfleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow nbrfwrap()'s to do buffer switches
 * instead of setting up a fresh nbrfin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void nbrfrestart (FILE *input_file  );
void nbrf_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE nbrf_create_buffer (FILE *file,int size  );
void nbrf_delete_buffer (YY_BUFFER_STATE b  );
void nbrf_flush_buffer (YY_BUFFER_STATE b  );
void nbrfpush_buffer_state (YY_BUFFER_STATE new_buffer  );
void nbrfpop_buffer_state (void );

static void nbrfensure_buffer_stack (void );
static void nbrf_load_buffer_state (void );
static void nbrf_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER nbrf_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE nbrf_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE nbrf_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE nbrf_scan_bytes (yyconst char *bytes,int len  );

void *nbrfalloc (yy_size_t  );
void *nbrfrealloc (void *,yy_size_t  );
void nbrffree (void *  );

#define yy_new_buffer nbrf_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        nbrfensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            nbrf_create_buffer(nbrfin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        nbrfensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            nbrf_create_buffer(nbrfin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define nbrfwrap(n) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *nbrfin = (FILE *) 0, *nbrfout = (FILE *) 0;

typedef int yy_state_type;

extern int nbrflineno;

int nbrflineno = 1;

extern char *nbrftext;
#define yytext_ptr nbrftext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
#if defined(__GNUC__) && __GNUC__ >= 3
__attribute__((__noreturn__))
#endif
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up nbrftext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	nbrfleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 22
#define YY_END_OF_BUFFER 23
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[284] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       23,   21,   20,    1,   21,    6,    5,    4,    6,    6,
        6,    6,    8,   10,   11,   12,   13,   19,   17,   16,
       15,   14,   14,    0,    0,    0,    0,    0,    8,    7,
        9,    0,   12,   18,   14,   14,    2,    3,   12,   14,
       14,   12,   14,   14,   12,   14,   14,   12,   14,   14,
       12,   14,   14,   12,   14,   14,   12,   14,   14,   12,
       14,   14,   12,   14,   14,   12,   14,   14,   12,   14,
       14,   12,   14,   14,   12,   14,   14,   12,   14,   14,
       12,   14,   14,   12,   14,   14,   12,   14,   14,   12,

       14,   14,   12,   14,   14,   12,   14,   14,   12,   14,
       14,   12,   14,   14,   12,   14,   14,   12,   14,   14,
       12,   14,   14,   12,   14,   14,   12,   14,   14,   12,
       14,   14,   12,   14,   14,   12,   14,   14,   12,   14,
       14,   12,   14,   14,   12,   14,   14,   12,   14,   14,
       12,   14,   14,   12,   14,   14,   12,   14,   14,   12,
       14,   14,   12,   14,   14,   12,   14,   14,   12,   14,
       14,   12,   14,   14,   12,   14,   14,   12,   14,   14,
       12,   14,   14,   12,   14,   14,   12,   14,   14,   12,
       14,   14,   12,   14,   14,   12,   14,   14,   12,   14,

       14,   12,   14,   14,   12,   14,   14,   12,   14,   14,
       12,   14,   14,   12,   14,   14,   12,   14,   14,   12,
       14,   14,   12,   14,   14,   12,   14,   14,   12,   14,
       14,   12,   14,   14,   12,   14,   14,   12,   14,   14,
       12,   14,   14,   12,   14,   14,   12,   14,   14,   12,
       14,   14,   12,   14,   14,   12,   14,   14,   12,   14,
       14,   12,   14,   14,   12,   14,   14,   12,   14,   14,
       12,   14,   14,   12,   14,   14,   12,   14,   14,   12,
       14,   14,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    2,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    3,    1,    1,    1,    1,    1,    1,    1,    4,
        5,    6,    1,    7,    8,    9,   10,    1,   11,    1,
       12,    1,    1,    1,    1,    1,    1,    1,   13,    1,
       14,   15,   16,    1,   17,   17,   18,   19,   17,   20,
       17,   17,   17,   17,   17,   18,   17,   21,   17,   20,
       17,   22,   17,   17,   17,   17,   17,   17,   17,   17,
        1,    1,    1,    1,    1,    1,   17,   17,   17,   19,

       17,   20,   17,   17,   17,   17,   17,   18,   17,   21,
       17,   20,   17,   22,   17,   17,   17,   17,   17,   17,
       17,   17,    1,    1,    1,   23,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[24] =
    {   0,
        1,    2,    3,    1,    1,    4,    1,    4,    1,    1,
        1,    1,    1,    1,    1,    4,    4,    4,    4,    4,
        4,    4,    4
    } ;

static yyconst flex_int16_t yy_base[448] =
    {   0,
      752,    0,   14,   35,    1,    3,  748,  744,   57,    0,
      742,  925,  925,  925,   62,  925,  925,  925,    0,  727,
        1,  716,    0,  925,    5,    0,  925,  925,  715,  925,
      925,    1,    6,    8,  715,    9,  704,  705,    0,   28,
      925,   36,    0,  925,   24,   77,  925,  925,    0,   78,
       79,    0,   80,   81,    0,   82,   83,    0,   99,  100,
        0,  101,  102,    0,  103,  104,    0,  105,  121,    0,
      122,  123,    0,  124,  125,    0,  126,  127,    0,  143,
      144,    0,  145,  146,    0,  147,  148,    0,  149,  165,
        0,  166,  167,    0,  168,  169,    0,  170,  171,    0,

      187,  188,    0,  189,  190,    0,  191,  192,    0,  193,
      209,    0,  210,  211,    0,  212,  213,    0,  214,  215,
        0,  231,  232,    0,  233,  234,    0,  235,  236,    0,
      237,  253,    0,  254,  255,    0,  256,  257,    0,  258,
      259,    0,  275,  276,    0,  277,  278,    0,  279,  280,
        0,  281,  297,    0,  298,  299,    0,  300,  301,    0,
      302,  303,    0,  319,  320,    0,  321,  322,    0,  323,
      324,    0,  325,  341,    0,  342,  343,    0,  344,  345,
        0,  346,  347,    0,  363,  364,    0,  365,  366,    0,
      367,  368,    0,  369,  385,    0,  386,  387,    0,  388,

      389,    0,  390,  391,    0,  407,  408,    0,  409,  410,
        0,  411,  412,    0,  413,  429,    0,  430,  431,    0,
      432,  433,    0,  434,  435,    0,  451,  452,    0,  453,
      454,    0,  455,  456,    0,  457,  473,    0,  474,  475,
        0,  476,  477,    0,  478,  479,    0,  495,  496,    0,
      497,  498,    0,  499,  500,    0,  501,  517,    0,  518,
      519,    0,  520,  521,    0,  522,  523,    0,  539,  540,
        0,  541,  542,    0,  543,  544,    0,  545,  561,  925,
      925,  925,  925,  584,  588,  592,  596,  600,  604,  608,
      710,  612,  706,  616,  702,  620,  698,  624,  694,  628,

      690,  632,  686,  636,  682,  640,  678,  644,  674,  648,
      670,  652,  666,  656,  662,  660,  658,  664,  654,  668,
      650,  672,  646,  676,  642,  680,  638,  684,  634,  688,
      630,  692,  626,  696,  622,  700,  618,  704,  614,  708,
      610,  712,  606,  716,  599,  720,  598,  724,  579,  728,
      578,  732,  577,  736,  576,  740,  575,  744,  574,  748,
      572,  752,  571,  756,  570,  760,  569,  764,  568,  768,
      567,  772,  566,  776,  550,  780,  528,  784,  506,  788,
      484,  792,  462,  796,  440,  800,  418,  804,  396,  808,
      374,  812,  352,  816,  330,  820,  308,  824,  286,  828,

      264,  832,  242,  836,  220,  840,  198,  844,  176,  848,
      154,  852,  132,  856,  110,  860,   88,  864,   49,  868,
       48,  872,   47,  876,   46,  880,   45,  884,   42,  888,
       41,  892,   40,  896,   39,  900,   38,  904,   37,  908,
       24,  912,   21,  916,   19,  920,    6
    } ;

static yyconst flex_int16_t yy_def[448] =
    {   0,
      284,  284,  285,  285,  286,  286,  287,  287,  283,    9,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  288,  283,  289,  290,  283,  283,  283,  283,
      283,  291,  291,  283,  283,  283,  283,  283,  288,  289,
      283,  283,  292,  283,  293,  293,  283,  283,  294,  295,
      295,  296,  297,  297,  298,  299,  299,  300,  301,  301,
      302,  303,  303,  304,  305,  305,  306,  307,  307,  308,
      309,  309,  310,  311,  311,  312,  313,  313,  314,  315,
      315,  316,  317,  317,  318,  319,  319,  320,  321,  321,
      322,  323,  323,  324,  325,  325,  326,  327,  327,  328,

      329,  329,  330,  331,  331,  332,  333,  333,  334,  335,
      335,  336,  337,  337,  338,  339,  339,  340,  341,  341,
      342,  343,  343,  344,  345,  345,  346,  347,  347,  348,
      349,  349,  350,  351,  351,  352,  353,  353,  354,  355,
      355,  356,  357,  357,  358,  359,  359,  360,  361,  361,
      362,  363,  363,  364,  365,  365,  366,  367,  367,  368,
      369,  369,  370,  371,  371,  372,  373,  373,  374,  375,
      375,  376,  377,  377,  378,  379,  379,  380,  381,  381,
      382,  383,  383,  384,  385,  385,  386,  387,  387,  388,
      389,  389,  390,  391,  391,  392,  393,  393,  394,  395,

      395,  396,  397,  397,  398,  399,  399,  400,  401,  401,
      402,  403,  403,  404,  405,  405,  406,  407,  407,  408,
      409,  409,  410,  411,  411,  412,  413,  413,  414,  415,
      415,  416,  417,  417,  418,  419,  419,  420,  421,  421,
      422,  423,  423,  424,  425,  425,  426,  427,  427,  428,
      429,  429,  430,  431,  431,  432,  433,  433,  434,  435,
      435,  436,  437,  437,  438,  439,  439,  440,  441,  441,
      442,  443,  443,  444,  445,  445,  446,  447,  447,  283,
      283,  283,    0,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,

      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,

      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283
    } ;

static yyconst flex_int16_t yy_nxt[949] =
    {   0,
      283,   14,   24,   25,   24,   25,   41,   42,   46,  281,
       38,   38,   38,   46,   15,   17,   46,   38,   47,   47,
       47,   46,  278,   46,  275,   47,   18,  272,   46,  283,
      283,   51,   19,   20,   21,   22,   17,   41,   42,   51,
      269,  266,  263,  260,  257,  254,   51,   18,  251,  248,
      245,  242,  239,   19,   20,   21,   22,   28,   29,   30,
       31,   31,   32,   31,   33,   31,   31,   28,   28,   28,
       31,   28,   33,   32,   32,   32,   32,   32,   32,   33,
       34,   35,   36,   37,   51,   54,   54,   57,   57,   60,
       60,  236,   51,   54,   54,   57,   57,   60,   60,   51,

       54,   54,   57,   57,   60,   60,   63,   63,   66,   66,
       69,   69,   72,  233,   63,   63,   66,   66,   69,   69,
       72,   63,   63,   66,   66,   69,   69,   72,   72,   75,
       75,   78,   78,   81,   81,  230,   72,   75,   75,   78,
       78,   81,   81,   72,   75,   75,   78,   78,   81,   81,
       84,   84,   87,   87,   90,   90,   93,  227,   84,   84,
       87,   87,   90,   90,   93,   84,   84,   87,   87,   90,
       90,   93,   93,   96,   96,   99,   99,  102,  102,  224,
       93,   96,   96,   99,   99,  102,  102,   93,   96,   96,
       99,   99,  102,  102,  105,  105,  108,  108,  111,  111,

      114,  221,  105,  105,  108,  108,  111,  111,  114,  105,
      105,  108,  108,  111,  111,  114,  114,  117,  117,  120,
      120,  123,  123,  218,  114,  117,  117,  120,  120,  123,
      123,  114,  117,  117,  120,  120,  123,  123,  126,  126,
      129,  129,  132,  132,  135,  215,  126,  126,  129,  129,
      132,  132,  135,  126,  126,  129,  129,  132,  132,  135,
      135,  138,  138,  141,  141,  144,  144,  212,  135,  138,
      138,  141,  141,  144,  144,  135,  138,  138,  141,  141,
      144,  144,  147,  147,  150,  150,  153,  153,  156,  209,
      147,  147,  150,  150,  153,  153,  156,  147,  147,  150,

      150,  153,  153,  156,  156,  159,  159,  162,  162,  165,
      165,  206,  156,  159,  159,  162,  162,  165,  165,  156,
      159,  159,  162,  162,  165,  165,  168,  168,  171,  171,
      174,  174,  177,  203,  168,  168,  171,  171,  174,  174,
      177,  168,  168,  171,  171,  174,  174,  177,  177,  180,
      180,  183,  183,  186,  186,  200,  177,  180,  180,  183,
      183,  186,  186,  177,  180,  180,  183,  183,  186,  186,
      189,  189,  192,  192,  195,  195,  198,  197,  189,  189,
      192,  192,  195,  195,  198,  189,  189,  192,  192,  195,
      195,  198,  198,  201,  201,  204,  204,  207,  207,  194,

      198,  201,  201,  204,  204,  207,  207,  198,  201,  201,
      204,  204,  207,  207,  210,  210,  213,  213,  216,  216,
      219,  191,  210,  210,  213,  213,  216,  216,  219,  210,
      210,  213,  213,  216,  216,  219,  219,  222,  222,  225,
      225,  228,  228,  188,  219,  222,  222,  225,  225,  228,
      228,  219,  222,  222,  225,  225,  228,  228,  231,  231,
      234,  234,  237,  237,  240,  185,  231,  231,  234,  234,
      237,  237,  240,  231,  231,  234,  234,  237,  237,  240,
      240,  243,  243,  246,  246,  249,  249,  182,  240,  243,
      243,  246,  246,  249,  249,  240,  243,  243,  246,  246,

      249,  249,  252,  252,  255,  255,  258,  258,  261,  179,
      252,  252,  255,  255,  258,  258,  261,  252,  252,  255,
      255,  258,  258,  261,  261,  264,  264,  267,  267,  270,
      270,  176,  261,  264,  264,  267,  267,  270,  270,  261,
      264,  264,  267,  267,  270,  270,  273,  273,  276,  276,
      279,  279,  282,  173,  273,  273,  276,  276,  279,  279,
      282,  273,  273,  276,  276,  279,  279,  282,  282,  170,
      167,  164,  161,  158,  155,  152,  282,  149,  146,  143,
      140,  137,  134,  282,   12,   12,   12,   12,   16,   16,
       16,   16,   23,   23,   23,   23,   26,   26,   26,   26,

       39,  131,  128,   39,   40,   40,   40,   40,   43,  125,
       43,   43,   49,  122,   49,   49,   52,  119,   52,   52,
       55,  116,   55,   55,   58,  113,   58,   58,   61,  110,
       61,   61,   64,  107,   64,   64,   67,  104,   67,   67,
       70,  101,   70,   70,   73,   98,   73,   73,   76,   95,
       76,   76,   79,   92,   79,   79,   82,   89,   82,   82,
       85,   86,   85,   85,   88,   83,   88,   88,   91,   80,
       91,   91,   94,   77,   94,   94,   97,   74,   97,   97,
      100,   71,  100,  100,  103,   68,  103,  103,  106,   65,
      106,  106,  109,   62,  109,  109,  112,   59,  112,  112,

      115,   56,  115,  115,  118,   53,  118,  118,  121,   50,
      121,  121,  124,   45,  124,  124,  127,   48,  127,  127,
      130,   47,  130,  130,  133,   47,  133,  133,  136,   44,
      136,  136,  139,   38,  139,  139,  142,   38,  142,  142,
      145,  283,  145,  145,  148,   27,  148,  148,  151,   27,
      151,  151,  154,   13,  154,  154,  157,  283,  157,  157,
      160,  283,  160,  160,  163,  283,  163,  163,  166,  283,
      166,  166,  169,  283,  169,  169,  172,  283,  172,  172,
      175,  283,  175,  175,  178,  283,  178,  178,  181,  283,
      181,  181,  184,  283,  184,  184,  187,  283,  187,  187,

      190,  283,  190,  190,  193,  283,  193,  193,  196,  283,
      196,  196,  199,  283,  199,  199,  202,  283,  202,  202,
      205,  283,  205,  205,  208,  283,  208,  208,  211,  283,
      211,  211,  214,  283,  214,  214,  217,  283,  217,  217,
      220,  283,  220,  220,  223,  283,  223,  223,  226,  283,
      226,  226,  229,  283,  229,  229,  232,  283,  232,  232,
      235,  283,  235,  235,  238,  283,  238,  238,  241,  283,
      241,  241,  244,  283,  244,  244,  247,  283,  247,  247,
      250,  283,  250,  250,  253,  283,  253,  253,  256,  283,
      256,  256,  259,  283,  259,  259,  262,  283,  262,  262,

      265,  283,  265,  265,  268,  283,  268,  268,  271,  283,
      271,  271,  274,  283,  274,  274,  277,  283,  277,  277,
      280,  283,  280,  280,   11,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283
    } ;

static yyconst flex_int16_t yy_chk[949] =
    {   0,
        0,    2,    5,    5,    6,    6,   25,   25,   32,  447,
       19,   21,   21,   33,    2,    3,   32,   19,   34,   36,
       36,   33,  445,   32,  443,   34,    3,  441,   33,   40,
       40,   45,    3,    3,    3,    3,    4,   42,   42,   45,
      439,  437,  435,  433,  431,  429,   45,    4,  427,  425,
      423,  421,  419,    4,    4,    4,    4,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
       15,   15,   15,   15,   46,   50,   51,   53,   54,   56,
       57,  417,   46,   50,   51,   53,   54,   56,   57,   46,

       50,   51,   53,   54,   56,   57,   59,   60,   62,   63,
       65,   66,   68,  415,   59,   60,   62,   63,   65,   66,
       68,   59,   60,   62,   63,   65,   66,   68,   69,   71,
       72,   74,   75,   77,   78,  413,   69,   71,   72,   74,
       75,   77,   78,   69,   71,   72,   74,   75,   77,   78,
       80,   81,   83,   84,   86,   87,   89,  411,   80,   81,
       83,   84,   86,   87,   89,   80,   81,   83,   84,   86,
       87,   89,   90,   92,   93,   95,   96,   98,   99,  409,
       90,   92,   93,   95,   96,   98,   99,   90,   92,   93,
       95,   96,   98,   99,  101,  102,  104,  105,  107,  108,

      110,  407,  101,  102,  104,  105,  107,  108,  110,  101,
      102,  104,  105,  107,  108,  110,  111,  113,  114,  116,
      117,  119,  120,  405,  111,  113,  114,  116,  117,  119,
      120,  111,  113,  114,  116,  117,  119,  120,  122,  123,
      125,  126,  128,  129,  131,  403,  122,  123,  125,  126,
      128,  129,  131,  122,  123,  125,  126,  128,  129,  131,
      132,  134,  135,  137,  138,  140,  141,  401,  132,  134,
      135,  137,  138,  140,  141,  132,  134,  135,  137,  138,
      140,  141,  143,  144,  146,  147,  149,  150,  152,  399,
      143,  144,  146,  147,  149,  150,  152,  143,  144,  146,

      147,  149,  150,  152,  153,  155,  156,  158,  159,  161,
      162,  397,  153,  155,  156,  158,  159,  161,  162,  153,
      155,  156,  158,  159,  161,  162,  164,  165,  167,  168,
      170,  171,  173,  395,  164,  165,  167,  168,  170,  171,
      173,  164,  165,  167,  168,  170,  171,  173,  174,  176,
      177,  179,  180,  182,  183,  393,  174,  176,  177,  179,
      180,  182,  183,  174,  176,  177,  179,  180,  182,  183,
      185,  186,  188,  189,  191,  192,  194,  391,  185,  186,
      188,  189,  191,  192,  194,  185,  186,  188,  189,  191,
      192,  194,  195,  197,  198,  200,  201,  203,  204,  389,

      195,  197,  198,  200,  201,  203,  204,  195,  197,  198,
      200,  201,  203,  204,  206,  207,  209,  210,  212,  213,
      215,  387,  206,  207,  209,  210,  212,  213,  215,  206,
      207,  209,  210,  212,  213,  215,  216,  218,  219,  221,
      222,  224,  225,  385,  216,  218,  219,  221,  222,  224,
      225,  216,  218,  219,  221,  222,  224,  225,  227,  228,
      230,  231,  233,  234,  236,  383,  227,  228,  230,  231,
      233,  234,  236,  227,  228,  230,  231,  233,  234,  236,
      237,  239,  240,  242,  243,  245,  246,  381,  237,  239,
      240,  242,  243,  245,  246,  237,  239,  240,  242,  243,

      245,  246,  248,  249,  251,  252,  254,  255,  257,  379,
      248,  249,  251,  252,  254,  255,  257,  248,  249,  251,
      252,  254,  255,  257,  258,  260,  261,  263,  264,  266,
      267,  377,  258,  260,  261,  263,  264,  266,  267,  258,
      260,  261,  263,  264,  266,  267,  269,  270,  272,  273,
      275,  276,  278,  375,  269,  270,  272,  273,  275,  276,
      278,  269,  270,  272,  273,  275,  276,  278,  279,  373,
      371,  369,  367,  365,  363,  361,  279,  359,  357,  355,
      353,  351,  349,  279,  284,  284,  284,  284,  285,  285,
      285,  285,  286,  286,  286,  286,  287,  287,  287,  287,

      288,  347,  345,  288,  289,  289,  289,  289,  290,  343,
      290,  290,  292,  341,  292,  292,  294,  339,  294,  294,
      296,  337,  296,  296,  298,  335,  298,  298,  300,  333,
      300,  300,  302,  331,  302,  302,  304,  329,  304,  304,
      306,  327,  306,  306,  308,  325,  308,  308,  310,  323,
      310,  310,  312,  321,  312,  312,  314,  319,  314,  314,
      316,  317,  316,  316,  318,  315,  318,  318,  320,  313,
      320,  320,  322,  311,  322,  322,  324,  309,  324,  324,
      326,  307,  326,  326,  328,  305,  328,  328,  330,  303,
      330,  330,  332,  301,  332,  332,  334,  299,  334,  334,

      336,  297,  336,  336,  338,  295,  338,  338,  340,  293,
      340,  340,  342,  291,  342,  342,  344,   38,  344,  344,
      346,   37,  346,  346,  348,   35,  348,  348,  350,   29,
      350,  350,  352,   22,  352,  352,  354,   20,  354,  354,
      356,   11,  356,  356,  358,    8,  358,  358,  360,    7,
      360,  360,  362,    1,  362,  362,  364,    0,  364,  364,
      366,    0,  366,  366,  368,    0,  368,  368,  370,    0,
      370,  370,  372,    0,  372,  372,  374,    0,  374,  374,
      376,    0,  376,  376,  378,    0,  378,  378,  380,    0,
      380,  380,  382,    0,  382,  382,  384,    0,  384,  384,

      386,    0,  386,  386,  388,    0,  388,  388,  390,    0,
      390,  390,  392,    0,  392,  392,  394,    0,  394,  394,
      396,    0,  396,  396,  398,    0,  398,  398,  400,    0,
      400,  400,  402,    0,  402,  402,  404,    0,  404,  404,
      406,    0,  406,  406,  408,    0,  408,  408,  410,    0,
      410,  410,  412,    0,  412,  412,  414,    0,  414,  414,
      416,    0,  416,  416,  418,    0,  418,  418,  420,    0,
      420,  420,  422,    0,  422,  422,  424,    0,  424,  424,
      426,    0,  426,  426,  428,    0,  428,  428,  430,    0,
      430,  430,  432,    0,  432,  432,  434,    0,  434,  434,

      436,    0,  436,  436,  438,    0,  438,  438,  440,    0,
      440,  440,  442,    0,  442,  442,  444,    0,  444,  444,
      446,    0,  446,  446,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int nbrf_flex_debug;
int nbrf_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *nbrftext;
#line 1 "sequence/nbrfl.l"
/* nbrfl.l - NBRF sequence lexer */
#line 4 "sequence/nbrfl.l"
#ifdef HAVE_CONFIG_H
# include <config.h>
#endif

#ifdef STDC_HEADERS
# include <stdlib.h>
# include <string.h>
#endif

#include "sequence/nbrfy.h"
#define YY_NO_INPUT 1

#line 828 "sequence/nbrfl.c"

#define INITIAL 0
#define HTAG 1
#define HNAM 2
#define DESC 3
#define SEQS 4

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int nbrflex_destroy (void );

int nbrfget_debug (void );

void nbrfset_debug (int debug_flag  );

YY_EXTRA_TYPE nbrfget_extra (void );

void nbrfset_extra (YY_EXTRA_TYPE user_defined  );

FILE *nbrfget_in (void );

void nbrfset_in  (FILE * _in_str  );

FILE *nbrfget_out (void );

void nbrfset_out  (FILE * _out_str  );

int nbrfget_leng (void );

char *nbrfget_text (void );

int nbrfget_lineno (void );

void nbrfset_lineno (int _line_number  );

YYSTYPE * nbrfget_lval (void );

void nbrfset_lval (YYSTYPE * yylval_param  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int nbrfwrap (void );
#else
extern int nbrfwrap (void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( nbrftext, nbrfleng, 1, nbrfout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( nbrfin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( nbrfin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, nbrfin))==0 && ferror(nbrfin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(nbrfin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int nbrflex \
               (YYSTYPE * yylval_param );

#define YY_DECL int nbrflex \
               (YYSTYPE * yylval_param )
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after nbrftext and nbrfleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( nbrfleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(nbrftext[nbrfleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
        YYSTYPE * yylval;
    
#line 46 "sequence/nbrfl.l"


#line 1030 "sequence/nbrfl.c"

    yylval = yylval_param;

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! nbrfin )
			nbrfin = stdin;

		if ( ! nbrfout )
			nbrfout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			nbrfensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				nbrf_create_buffer(nbrfin,YY_BUF_SIZE );
		}

		nbrf_load_buffer_state( );
		}

	while (/*CONSTCOND*/ 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of nbrftext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 284 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 283 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 48 "sequence/nbrfl.l"
; /* Empty lines ignored */
	YY_BREAK
case 2:
*yy_cp = (yy_hold_char); /* undo effects of setting up nbrftext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up nbrftext again */
YY_RULE_SETUP
#line 50 "sequence/nbrfl.l"
{ BEGIN HTAG; return SUP; }
	YY_BREAK
case 3:
*yy_cp = (yy_hold_char); /* undo effects of setting up nbrftext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up nbrftext again */
YY_RULE_SETUP
#line 51 "sequence/nbrfl.l"
{ return TAG; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 52 "sequence/nbrfl.l"
{ BEGIN HNAM; return SEM; }
	YY_BREAK
case 5:
/* rule 5 can match eol */
YY_RULE_SETUP
#line 53 "sequence/nbrfl.l"
{ return ERR; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 54 "sequence/nbrfl.l"
{ return ERR; }
	YY_BREAK
case 7:
*yy_cp = (yy_hold_char); /* undo effects of setting up nbrftext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up nbrftext again */
YY_RULE_SETUP
#line 56 "sequence/nbrfl.l"
; /* Leading spaces ignored */
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 57 "sequence/nbrfl.l"
{ yylval->str = strdup(nbrftext); return NAM; }
	YY_BREAK
case 9:
/* rule 9 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up nbrftext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up nbrftext again */
YY_RULE_SETUP
#line 58 "sequence/nbrfl.l"
; /* Trailing spaces ignored */
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 59 "sequence/nbrfl.l"
{ BEGIN DESC; return EOL; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 60 "sequence/nbrfl.l"
{ return ERR; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 62 "sequence/nbrfl.l"
{ yylval->str = strdup(nbrftext); return TXT; }
	YY_BREAK
case 13:
/* rule 13 can match eol */
YY_RULE_SETUP
#line 63 "sequence/nbrfl.l"
{ BEGIN SEQS; return EOL; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 65 "sequence/nbrfl.l"
{ yylval->str = strdup(nbrftext); return BAS; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 66 "sequence/nbrfl.l"
; /* Punctuation ignored */
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 67 "sequence/nbrfl.l"
; /* Spaces ignored */
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 68 "sequence/nbrfl.l"
; /* Newlines ignored */
	YY_BREAK
case 18:
/* rule 18 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up nbrftext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up nbrftext again */
YY_RULE_SETUP
#line 69 "sequence/nbrfl.l"
{ BEGIN INITIAL; return END; }
	YY_BREAK
case YY_STATE_EOF(SEQS):
#line 70 "sequence/nbrfl.l"
{ BEGIN INITIAL; return END; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 71 "sequence/nbrfl.l"
{ return ERR; }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(HTAG):
case YY_STATE_EOF(HNAM):
case YY_STATE_EOF(DESC):
#line 73 "sequence/nbrfl.l"
{ return NUL; }
	YY_BREAK
case 20:
/* rule 20 can match eol */
YY_RULE_SETUP
#line 74 "sequence/nbrfl.l"
{ return ERR; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 75 "sequence/nbrfl.l"
{ return ERR; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 77 "sequence/nbrfl.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 1256 "sequence/nbrfl.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed nbrfin at a new source and called
			 * nbrflex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = nbrfin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( nbrfwrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * nbrftext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of nbrflex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					nbrfrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			nbrfrestart(nbrfin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) nbrfrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 284 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 284 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 283);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					nbrfrestart(nbrfin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( nbrfwrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve nbrftext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void nbrfrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        nbrfensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            nbrf_create_buffer(nbrfin,YY_BUF_SIZE );
	}

	nbrf_init_buffer(YY_CURRENT_BUFFER,input_file );
	nbrf_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void nbrf_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		nbrfpop_buffer_state();
	 *		nbrfpush_buffer_state(new_buffer);
     */
	nbrfensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	nbrf_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (nbrfwrap()) processing, but the only time this flag
	 * is looked at is after nbrfwrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void nbrf_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	nbrfin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE nbrf_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) nbrfalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in nbrf_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) nbrfalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in nbrf_create_buffer()" );

	b->yy_is_our_buffer = 1;

	nbrf_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with nbrf_create_buffer()
 * 
 */
    void nbrf_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		nbrffree((void *) b->yy_ch_buf  );

	nbrffree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a nbrfrestart() or at EOF.
 */
    static void nbrf_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	nbrf_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then nbrf_init_buffer was _probably_
     * called from nbrfrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void nbrf_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		nbrf_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void nbrfpush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	nbrfensure_buffer_stack();

	/* This block is copied from nbrf_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from nbrf_switch_to_buffer. */
	nbrf_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void nbrfpop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	nbrf_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		nbrf_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void nbrfensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)nbrfalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in nbrfensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)nbrfrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in nbrfensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE nbrf_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) nbrfalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in nbrf_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	nbrf_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to nbrflex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       nbrf_scan_bytes() instead.
 */
YY_BUFFER_STATE nbrf_scan_string (yyconst char * yystr )
{
    
	return nbrf_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to nbrflex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE nbrf_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) nbrfalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in nbrf_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = nbrf_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in nbrf_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up nbrftext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		nbrftext[nbrfleng] = (yy_hold_char); \
		(yy_c_buf_p) = nbrftext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		nbrfleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int nbrfget_lineno  (void)
{
        
    return nbrflineno;
}

/** Get the input stream.
 * 
 */
FILE *nbrfget_in  (void)
{
        return nbrfin;
}

/** Get the output stream.
 * 
 */
FILE *nbrfget_out  (void)
{
        return nbrfout;
}

/** Get the length of the current token.
 * 
 */
int nbrfget_leng  (void)
{
        return nbrfleng;
}

/** Get the current token.
 * 
 */

char *nbrfget_text  (void)
{
        return nbrftext;
}

/** Set the current line number.
 * @param _line_number
 * 
 */
void nbrfset_lineno (int  _line_number )
{
    
    nbrflineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see nbrf_switch_to_buffer
 */
void nbrfset_in (FILE *  _in_str )
{
        nbrfin = _in_str ;
}

void nbrfset_out (FILE *  _out_str )
{
        nbrfout = _out_str ;
}

int nbrfget_debug  (void)
{
        return nbrf_flex_debug;
}

void nbrfset_debug (int  _bdebug )
{
        nbrf_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from nbrflex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    nbrfin = stdin;
    nbrfout = stdout;
#else
    nbrfin = (FILE *) 0;
    nbrfout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * nbrflex_init()
     */
    return 0;
}

/* nbrflex_destroy is for both reentrant and non-reentrant scanners. */
int nbrflex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		nbrf_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		nbrfpop_buffer_state();
	}

	/* Destroy the stack itself. */
	nbrffree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * nbrflex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *nbrfalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *nbrfrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void nbrffree (void * ptr )
{
	free( (char *) ptr );	/* see nbrfrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 77 "sequence/nbrfl.l"



